@@ -26,14 +26,15 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <nm-vpn-plugin.h>
+
+#include <NetworkManager.h>
+#include <nm-vpn-service-plugin.h>
 
 #include "nm-fortisslvpn-service-defines.h"
 
 #define DBUS_TYPE_G_MAP_OF_VARIANT (dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE))
 
 /* For the pppd plugin <-> VPN plugin service */
-#define NM_DBUS_SERVICE_FORTISSLVPN_PPP    "org.freedesktop.NetworkManager.fortisslvpn-ppp"
 #define NM_DBUS_PATH_FORTISSLVPN_PPP       "/org/freedesktop/NetworkManager/fortisslvpn/ppp"
 #define NM_DBUS_INTERFACE_FORTISSLVPN_PPP  "org.freedesktop.NetworkManager.fortisslvpn.ppp"
 
@@ -45,15 +46,15 @@
 #define NM_FORTISSLVPN_PLUGIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NM_TYPE_FORTISSLVPN_PLUGIN, NMFortisslvpnPluginClass))
 
 typedef struct {
-	NMVPNPlugin parent;
+	NMVpnServicePlugin parent;
 } NMFortisslvpnPlugin;
 
 typedef struct {
-	NMVPNPluginClass parent;
+	NMVpnServicePluginClass parent;
 } NMFortisslvpnPluginClass;
 
 GType nm_fortisslvpn_plugin_get_type (void);
 
-NMFortisslvpnPlugin *nm_fortisslvpn_plugin_new (void);
+NMFortisslvpnPlugin *nm_fortisslvpn_plugin_new (const char *bus_name);
 
 #endif /* NM_FORTISSLVPN_SERVICE_H */
